using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace TimerInterrupt
{
    public partial class TimerInterrupt : Form
    {
        /// <summary>
        /// Handle to the first board
        /// </summary>
        PCIe3121_NET.PCIe3121 board;

        /// <summary>
        /// Some internal value. Store the number of interrupt per component
        /// </summary>
        private int timer1InterruptNb = 0;

        /// <summary>
        /// Constructor of the form
        /// </summary>
        public TimerInterrupt()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Called at the first load
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void TimerInterrupt_Load(object sender, EventArgs e)
        {
            int ret = 0;

            // Open the first board of the system
            this.board = PCIe3121_NET.PCIe3121.OpenBoard(0);
            // Error handling
            if (this.board == null)
            {
                MessageBox.Show("Error OpenBoard returned null");
                this.Close();
                return;
            }

            // Enable the interruption
            if ((ret = this.board.SetBoardIntRoutine()) != 0)
            {
                MessageBox.Show("Error " + ret.ToString() + " in SetBoardIntRoutine");
                this.Close();
                return;
            }

            // Stop the components. No check since if nothing is started the function will failed
            this.board.StopTimer(0);

            // Listen to the counter timer watchdog interruption
            this.board.TimerEventReceived += new PCIe3121_NET.PCIe3121.TimerEventHandler(board_TimerEventReceived);
        }

        void board_TimerEventReceived(object source, PCIe3121_NET.TimerEventArgs args)
        {
            // Counter timer 1
            this.timer1InterruptNb++;
        }

        /// <summary>
        /// Display timer for timer 1 ticks
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void timer1DisplayTimer_Tick(object sender, EventArgs e)
        {
            int ret = 0;
            byte status = 0;
            byte softwareTriggerStatus = 0;
            ushort value = 0;
            // Read the value
            if ((ret = this.board.ReadTimerStatus(0, ref status, ref softwareTriggerStatus, ref value)) != 0)
            {
                MessageBox.Show("Error " + ret.ToString() + " in ReadTimerStatus");
                return;
            }
            timer1Value.Text = value.ToString();
            timer1Interrupt.Text = this.timer1InterruptNb.ToString();
        }

        /// <summary>
        /// Occurs while the form is closing
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void TimerInterrupt_FormClosing(object sender, FormClosingEventArgs e)
        {
            int ret = 0;
            // Stop the timers
            this.board.StopTimer(0);

            // Disable the interruption
            if ((ret = this.board.ResetBoardIntRoutine()) != 0)
            {
                MessageBox.Show("Error " + ret.ToString() + " in ResetBoardIntRoutine");
                return;
            }
        }

        /// <summary>
        /// Click on the start button for the timer 1
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void timer1Start_Click(object sender, EventArgs e)
        {
            int ret = 0;
            // Initialize and start the timer
            if ((ret = this.board.InitAndStartTimer(0, /* timer 0 */
                0, /* mode 2 */
                1, /* ms time base */
                0, /* output disabled */
                1, /* interrupt enabled */
                5000, /* 5000 ms */
                0 /* watchdog disabled */)) != 0)
            {
                MessageBox.Show("Error " + ret.ToString() + " in InitAndStartTimer");
                return;
            }
            // Disable/enable button
            timer1Start.Enabled = false;
            timer1Stop.Enabled = true;
            timer1Trigger.Enabled = true;
            // Start the display timer
            timer1DisplayTimer.Start();
        }

        /// <summary>
        /// Click on the stop button for the timer 1
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void timer1Stop_Click(object sender, EventArgs e)
        {
            int ret = 0;
            // Stop the timer
            if ((ret = this.board.StopTimer(0)) != 0)
            {
                MessageBox.Show("Error " + ret.ToString() + " in StopTimer");
                return;
            }
            // Disable/enable button
            timer1Start.Enabled = true;
            timer1Stop.Enabled = false;
            timer1Trigger.Enabled = false;
            // Stop the display timer
            timer1DisplayTimer.Stop();
        }

        /// <summary>
        /// Click on the trigger button for the timer 1
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void timer1Trigger_Click(object sender, EventArgs e)
        {
            int ret = 0;
            // Read the value
            if ((ret = this.board.TriggerTimer(0)) != 0)
            {
                MessageBox.Show("Error " + ret.ToString() + " in TriggerTimer");
                return;
            }
        }
    }
}